<?php
// wcf imports
require_once(WCF_DIR.'lib/action/AbstractAction.class.php');
require_once(WCF_DIR.'lib/data/socialBookmark/SocialBookmarkProviderEditor.class.php');

/**
 * Changes the status of a social bookmark provider.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2010 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.wcf.socialBookmarks
 * @subpackage	acp.action
 * @category 	Community Framework
 */
class SocialBookmarkProviderChangeStatusAction extends AbstractAction {
	/**
	 * social bookmark provider id
	 * 
	 * @var	integer
	 */
	public $providerID = 0;
	
	/**
	 * SocialBookmarkProviderEditor object
	 * 
	 * @var	SocialBookmarkProviderEditor
	 */
	public $socialBookmarkProvider;
	
	/**
	 * @see Action::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_REQUEST['providerID'])) $this->providerID = intval($_REQUEST['providerID']);
		$this->socialBookmarkProvider = new SocialBookmarkProviderEditor($this->providerID);
		if (!$this->socialBookmarkProvider->providerID) {
			throw new IllegalLinkException();
		}
	}
	
	/**
	 * @see Action::execute()
	 */
	public function execute() {
		parent::execute();

		// check permission.
		WCF::getUser()->checkPermission('admin.socialBookmark.canEditSocialBookmarkProvider');

		// change status
		$this->socialBookmarkProvider->enable(($this->socialBookmarkProvider->enabled != 1));
		$this->executed();
		
		// clear cache
		WCF::getCache()->clear(WCF_DIR.'cache/', 'cache.socialBookmarkProvider.php');
		
		// redirect to the view page.
		HeaderUtil::redirect('index.php?page=SocialBookmarkProviderList&packageID='.PACKAGE_ID.SID_ARG_2ND_NOT_ENCODED);
		exit;
	}
}
?>