<?php
// wcf imports
require_once(WCF_DIR.'lib/acp/form/ACPForm.class.php');
require_once(WCF_DIR.'lib/data/socialBookmark/SocialBookmarkProviderEditor.class.php');

/**
 * Shows the form for adding new social bookmark providers.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2010 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.wcf.socialBookmarks
 * @subpackage	acp.form
 * @category 	Community Framework
 */
class SocialBookmarkProviderAddForm extends ACPForm {
	// system
	public $action = 'add';
	public $activeMenuItem = 'wcf.acp.menu.link.socialBookmark.provider.add';
	public $neededPermissions = 'admin.socialBookmark.canAddSocialBookmarkProvider';
	public $templateName = 'socialBookmarkProviderAdd';
	
	// parameters
	public $providerImage = '';
	public $showOrder = '';
	public $title = '';
	public $url = '';
	
	/**
	 * SocialBookmarkProvider object
	 * 
	 * @var	SocialBookmarkProvider
	 */
	public $socialBookmarkProvider = null;
	
	/**
	 * @see	Form::readFormParameters()
	 */
	public function readFormParameters() {
		parent::readFormParameters();
		
		if (isset($_POST['providerImage'])) $this->providerImage = StringUtil::trim($_POST['providerImage']);
		if (isset($_POST['showOrder'])) $this->showOrder = intval($_POST['showOrder']);
		if (isset($_POST['title'])) $this->title = StringUtil::trim($_POST['title']);
		if (isset($_POST['url'])) $this->url = StringUtil::trim($_POST['url']);
	}
	
	/**
	 * @see	Form::validate()
	 */
	public function validate() {
		parent::validate();
		
		if (empty($this->title)) {
			throw new UserInputException('title');
		}
		
		if (empty($this->url)) {
			throw new UserInputException('url');
		}
		
		if (empty($this->providerImage)) {
			throw new UserInputException('providerImage');
		}
		
		// validate url schema
		if (strpos($this->url, '%s') === false) {
			if (strpos($this->url, '%1$s') === false) {
				throw new UserInputException('url', 'notValid');
			}
		}
		
		$this->validateTitle();
	}
	
	/**
	 * Validates the provider name.
	 */
	protected function validateTitle() {
		// check for duplicate entries
		$sql = "SELECT	COUNT(*) AS count
			FROM	wcf".WCF_N."_social_bookmark_provider
			WHERE	title LIKE '".escapeString($this->title)."'";
		$row = WCF::getDB()->getFirstRow($sql);
		
		if ($row['count']) {
			throw new UserInputException('title', 'notUnique');
		}
	}
	
	/**
	 * @see	Form::save()
	 */
	public function save() {
		parent::save();
		
		$this->socialBookmarkProvider = SocialBookmarkProviderEditor::create($this->title, $this->url, $this->providerImage, $this->showOrder);
		
		// call saved event
		$this->saved();
		
		// reset variables
		$this->providerImage = $this->showOrder = $this->title = $this->url = '';
		
		// clear cache
		WCF::getCache()->clear(WCF_DIR.'cache/', 'cache.socialBookmarkProvider.php');
		
		// show success message
		WCF::getTPL()->assign('success', true);
	}
	
	/**
	 * @see	Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'providerImage' => $this->providerImage,
			'showOrder' => $this->showOrder,
			'title' => $this->title,
			'url' => $this->url
		));
	}
}
?>