<?php
// wcf imports
require_once(WCF_DIR.'lib/acp/form/SocialBookmarkProviderAddForm.class.php');

/**
 * Shows the form for editing new social bookmark providers.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2010 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.wcf.socialBookmarks
 * @subpackage	acp.form
 * @category 	Community Framework
 */
class SocialBookmarkProviderEditForm extends SocialBookmarkProviderAddForm {
	// system
	public $action = 'edit';
	public $activeMenuItem = 'wcf.acp.menu.link.content.socialBookmark';
	public $neededPermissions = 'admin.socialBookmark.canEditSocialBookmarkProvider';
	
	// parameters
	public $providerID = 0;
	
	/**
	 * @see	Page::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_REQUEST['providerID'])) { 
			$this->providerID = intval($_REQUEST['providerID']);
			$this->socialBookmarkProvider = new SocialBookmarkProviderEditor($this->providerID);
			if ($this->socialBookmarkProvider->providerID == 0) {
				throw new IllegalLinkException();
			}
		}
	}
	
	/**
	 * @see	Page::readData()
	 */
	public function readData() {
		parent::readData();
		
		// default values
		if (!count($_POST)) {
			$this->title = $this->socialBookmarkProvider->title;
			$this->url = $this->socialBookmarkProvider->url;
			$this->providerImage = $this->socialBookmarkProvider->providerImage;
			$this->showOrder = $this->socialBookmarkProvider->showOrder;
		}
	}
	
	/**
	 * @see	SocialBookmarkProviderAddForm::validateTitle()
	 */
	protected function validateTitle() {
		// check for duplicate entries
		$sql = "SELECT	COUNT(*) AS count
			FROM	wcf".WCF_N."_social_bookmark_provider
			WHERE	title LIKE '".escapeString($this->title)."'
				AND providerID <> ".$this->providerID;
		$row = WCF::getDB()->getFirstRow($sql);
		
		if ($row['count']) {
			throw new UserInputException('title', 'notUnique');
		}
	}
	
	/**
	 * @see	Form::save()
	 */
	public function save() {
		ACPForm::save();
		
		$this->socialBookmarkProvider->update($this->title, $this->url, $this->providerImage, $this->showOrder);
		
		// call saved event
		$this->saved();
		
		// clear cache
		WCF::getCache()->clear(WCF_DIR.'cache/', 'cache.socialBookmarkProvider.php');
		
		// show success message
		WCF::getTPL()->assign('success', true);
	}
	
	/**
	 * @see	Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'providerID' => $this->providerID
		));
	}
}
?>