<?php
// wcf imports
require_once(WCF_DIR.'lib/page/SortablePage.class.php');
require_once(WCF_DIR.'lib/data/socialBookmark/SocialBookmarkProviderList.class.php');

/**
 * Lists social bookmark provider.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2010 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.wcf.socialBookmarks
 * @subpackage	acp.page
 * @category 	Community Framework
 */
class SocialBookmarkProviderListPage extends SortablePage {
	// system
	public $count = 0;
	public $defaultSortField = 'showOrder';
	public $deletedProviderID = 0;
	public $templateName = 'socialBookmarkProviderList';
	
	/**
	 * social bookmark provider list object
	 * 
	 * @var	SocialBookmarkProviderList
	 */
	public $socialBookmarkProviderList = null;
	
	/**
	 * @see Page::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		$this->socialBookmarkProviderList = new SocialBookmarkProviderList();
		if (isset($_REQUEST['deletedProviderID'])) $this->deletedProviderID = intval($_REQUEST['deletedProviderID']);
	}
	
	/**
	 * @see Page::readData()
	 */
	public function readData() {
		parent::readData();
		
		// read objects
		$this->socialBookmarkProviderList->sqlOffset = ($this->pageNo - 1) * $this->itemsPerPage;
		$this->socialBookmarkProviderList->sqlLimit = $this->itemsPerPage;
		$this->socialBookmarkProviderList->sqlOrderBy = $this->sortField." ".$this->sortOrder;
		$this->socialBookmarkProviderList->readObjects();
	}
	
	/**
	 * @see SortablePage::validateSortField()
	 */
	public function validateSortField() {
		parent::validateSortField();
		
		switch ($this->sortField) {
			case 'providerID':
			case 'title':
			case 'showOrder': break;
			default: $this->sortField = $this->defaultSortField;
		}
	}
	
	/**
	 * @see MultipleLinkPage::countItems()
	 */
	public function countItems() {
		parent::countItems();
		
		$this->count = $this->socialBookmarkProviderList->countObjects();
		
		return $this->count;
	}
	
	/**
	 * @see Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'count' => $this->count,
			'deletedProviderID' => $this->deletedProviderID,
			'socialBookmarkProviderList' => $this->socialBookmarkProviderList->getObjects()
			
		));
	}
	
	/**
	 * @see Page::show()
	 */
	public function show() {
		// enable menu item
		WCFACP::getMenu()->setActiveMenuItem('wcf.acp.menu.link.socialBookmark.provider.list');
		
		// check permission
		WCF::getUser()->checkPermission(array('admin.socialBookmark.canEditSocialBookmarkProvider', 'admin.socialBookmark.canDeleteSocialBookmarkProvider'));
		
		parent::show();
	}
}
?>