<?php
// wcf imports
require_once(WCF_DIR.'lib/data/DatabaseObject.class.php');

/**
 * Represents a social bookmark provider.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2010 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.wcf.socialBookmarks
 * @subpackage	data
 * @category 	Community Framework
 */
class SocialBookmarkProvider extends DatabaseObject {
	/**
	 * list of social bookmark providers
	 * 
	 * @var	array<SocialBookmarkProvider>
	 */
	protected static $socialBookmarkProvider = null;
	
	/**
	 * Creates a new SocialBookmarkProvider object.
	 * 
	 * @param	integer		$providerID
	 * @param	array<mixed>	$row
	 */
	public function __construct($providerID, $row = null) {
		if ($row === null) {
			$sql = "SELECT	*
				FROM	wcf".WCF_N."_social_bookmark_provider
				WHERE	providerID = ".$providerID;
			$row = WCF::getDB()->getFirstRow($sql);
		}
		
		parent::__construct($row);
	}
	
	/**
	 * @see	DatabaseObject::handleData()
	 */
	protected function handleData($data) {
		if (isset($data['url'])) {
			$data['url'] = StringUtil::encodeHTML($data['url']);
		}
		
		parent::handleData($data);
	}
	
	/**
	 * Returns the title of this social bookmark provider.
	 * 
	 * @return	string
	 */
	public function __toString() {
		return $this->title;
	}
	
	/**
	 * Returns the bookmark link.
	 * 
	 * @return	string
	 */
	public function getLink() {
		$url = WCF::getTPL()->get('url');
		$title = WCF::getTPL()->get('title');
		
		return sprintf($this->url, rawurlencode($url), rawurlencode($title));
	}
	
	/**
	 * Returns the image of this social bookmark provider.
	 * 
	 * @return	string
	 */
	public function getImage() {
		return '<img src="'.(!preg_match('~^(/|https?://)~i', $this->providerImage) ? RELATIVE_WCF_DIR : '').StringUtil::encodeHTML($this->providerImage).'" alt="" />';
	}
	
	/**
	 * Returns a list of social bookmark providers
	 * 
	 * @var	array<SocialBookmarkProvider>
	 */
	public static function getProviders() {
		if (self::$socialBookmarkProvider === null) {
			WCF::getCache()->addResource(
				'socialBookmarkProvider',
				WCF_DIR.'cache/cache.socialBookmarkProvider.php',
				WCF_DIR.'lib/system/cache/CacheBuilderSocialBookmarkProvider.class.php'
			);
			self::$socialBookmarkProvider = WCF::getCache()->get('socialBookmarkProvider');
		}
		
		return self::$socialBookmarkProvider;
	}
}
?>