<?php
// wcf imports
require_once(WCF_DIR.'lib/data/socialBookmark/SocialBookmarkProvider.class.php');
require_once(WCF_DIR.'lib/system/event/EventHandler.class.php');

/**
 * Handles social bookmarks.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2010 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.wcf.socialBookmarks
 * @subpackage	data
 * @category 	Community Framework
 */
class SocialBookmarks {
	/**
	 * list of social bookmark providers
	 * 
	 * @var	array<SocialBookmarkProvider>
	 */
	public $providerList = array();
	
	/**
	 * template used for social bookmarks output
	 * 
	 * @var	string
	 */ 
	public $templateName = '';
	
	/**
	 * page title
	 * 
	 * @var	string
	 */
	public $title = '';
	
	/**
	 * page url
	 * 
	 * @var	string
	 */
	public $url = '';
	
	/**
	 * SocialBookmarks object
	 * 
	 * @var	SocialBookmarks
	 */
	private static $instance = null;
	
	/**
	 * Does nothing.
	 * 
	 * @see	SocialBookmarks::getInstance()
	 */
	protected function __construct() {}
	
	/**
	 * Does nothing.
	 * 
	 * @see	SocialBookmarks::getInstance()
	 */
	private final function __clone() {}
	
	/**
	 * Returns the current instance or spawns a unique one
	 * 
	 * @return	SocialBookmarks
	 */
	public static function getInstance() {
		if (self::$instance === null) {
			self::$instance = new SocialBookmarks();
		}
		
		return self::$instance;
	}
	
	/**
	 * Reads social bookmark provider from cache and returns a parsed template
	 * 
	 * @param	string		$url
	 * @param	string		$title
	 * @return	string
	 */
	public function getSocialBookmarks($url, $title = '') {
		$this->providerList = SocialBookmarkProvider::getProviders();
		$this->templateName = 'socialBookmarks';
		$this->title = $title;
		$this->url = $url;
		
		EventHandler::fireAction($this, 'shouldDisplay');
		
		if (count($this->providerList) == 0) return;
		
		WCF::getTPL()->assign(array(
			'providerList' => $this->providerList,
			'title' => $this->title,
			'url' => $this->url
		));
		
		return WCF::getTPL()->fetch($this->templateName);
	}
}
?>